==> cts_1.0-1.tar.gz: cts/src/resgen.f <==
      SUBROUTINE RESGEN
      INTEGER T
      DOUBLE PRECISION U,V
c      INCLUDE 'series.txt'
c      INCLUDE 'setcon.txt'
c      INCLUDE 'veccom.txt'
c      INCLUDE 'repcom.txt'
c      INCLUDE 'resgn2.txt'
C*****series.txt
      CHARACTER*40 NAME
      INTEGER LEN
      DOUBLE PRECISION TIM(500),SER(500),TDIF(500)
c      COMMON/SERIES/NAME,LEN,TIM,SER,TDIF
      COMMON/SERIES/TIM,SER,TDIF,NAME,LEN
C*****setcon.txt
      LOGICAL CONV,FAIL
      INTEGER NP,ITCT,PPIND
      DOUBLE PRECISION CSO,CSZ,LAM,SSOLD,GMOLD,GMNEW,SIGSQ,OLDB(22)
c      COMMON/SETCON/CONV,FAIL,NP,ITCT,PPIND,CSO,CSZ,LAM,SSOLD,
c     *GMOLD,GMNEW,SIGSQ,OLDB
      COMMON/SETCON/CSO,CSZ,LAM,SSOLD,
     *GMOLD,GMNEW,SIGSQ,OLDB,CONV,FAIL,NP,ITCT,PPIND
C*****veccom.txt
      DOUBLE PRECISION B(22),NEWB(22),PERB(22),DELB(22),
     * ERR(500),RES(500),PRES(22,500),sres(500)
      COMMON/VECCOM/B,NEWB,PERB,DELB,ERR,RES,PRES,sres
C*****repcom.txt
      LOGICAL PRPI
      INTEGER REQSW,KFSW
      DOUBLE PRECISION VOB
c      COMMON/REPCOM/PRPI,REQSW,VOB,KFSW
      COMMON/REPCOM/VOB,REQSW,KFSW,PRPI	
C*****resgn2.txt
      DOUBLE PRECISION WK(20),VT(500),BI(2,20,20),R(2,20,20),
     *RI(2,20,20)
c       DOUBLE PRECISION WK(20),VT(500),BI(2,20,20),R(20,20),RI(2,20,20)
      COMMON/RESGN2/WK,VT,BI,R,RI

c      print *,'PPIND: ',PPIND
      IF(PPIND.EQ.0)THEN
        PRINT *,'ROOT EQUALITY SWITCH: ',REQSW
      END IF
c      print *,'REQSW: ',REQSW
      IF(REQSW.EQ.0)THEN
        CALL RESG0
      ELSE
        CALL RESG1
c        PRINT *, 'CALL OF RESG1 COMPLETED'
      END IF
      U=CSZ
      DO 100 T=1,LEN
      U=U+DLOG(VT(T))
  100 CONTINUE
c      PRINT *,'SUM LOG VARIANCES FORMED'
      U=DEXP((CSO/LEN)*U)
      GMNEW=U
      DO 101 T=1,LEN
      V=ERR(T)*DSQRT(U/VT(T))
      IF(PPIND.EQ.0)THEN
        RES(T)=V
      ELSE
        PRES(PPIND,T)=V
      END IF
  101 CONTINUE
      RETURN
      END

==> cts_1.0-4.tar.gz: cts/src/resgen.f <==
      SUBROUTINE RESGEN
      IMPLICIT NONE
      INTEGER T
      DOUBLE PRECISION U,V
c      INCLUDE 'series.txt'
c      INCLUDE 'setcon.txt'
c      INCLUDE 'veccom.txt'
c      INCLUDE 'repcom.txt'
c      INCLUDE 'resgn2.txt'
C*****series.txt
      CHARACTER*40 NAME
      INTEGER LEN
      DOUBLE PRECISION TIM(500),SER(500),TDIF(500)
c      COMMON/SERIES/NAME,LEN,TIM,SER,TDIF
      COMMON/SERIES/TIM,SER,TDIF,NAME,LEN
C*****setcon.txt
      LOGICAL CONV,FAIL
      INTEGER NP,ITCT,PPIND
      DOUBLE PRECISION CSO,CSZ,LAM,SSOLD,GMOLD,GMNEW,SIGSQ,OLDB(22)
c      COMMON/SETCON/CONV,FAIL,NP,ITCT,PPIND,CSO,CSZ,LAM,SSOLD,
c     *GMOLD,GMNEW,SIGSQ,OLDB
      COMMON/SETCON/CSO,CSZ,LAM,SSOLD,
     *GMOLD,GMNEW,SIGSQ,OLDB,CONV,FAIL,NP,ITCT,PPIND
C*****veccom.txt
      DOUBLE PRECISION B(22),NEWB(22),PERB(22),DELB(22),
     * ERR(500),RES(500),PRES(22,500),sres(500)
      COMMON/VECCOM/B,NEWB,PERB,DELB,ERR,RES,PRES,sres
C*****repcom.txt
      LOGICAL PRPI
      INTEGER REQSW,KFSW
      DOUBLE PRECISION VOB
c      COMMON/REPCOM/PRPI,REQSW,VOB,KFSW
      COMMON/REPCOM/VOB,REQSW,KFSW,PRPI	
C*****resgn2.txt
      DOUBLE PRECISION WK(20),VT(500),BI(2,20,20),R(2,20,20),
     *RI(2,20,20)
c       DOUBLE PRECISION WK(20),VT(500),BI(2,20,20),R(20,20),RI(2,20,20)
      COMMON/RESGN2/WK,VT,BI,R,RI
      INTEGER PFI,ARP,VRI,CCV,LYAP,SCC,fct
      DOUBLE PRECISION SCALE,VR,CONST,PHI(20),PRDG
      COMMON/MODEL/SCALE,VR,CONST,PHI,PRDG,PFI,ARP,VRI,CCV,LYAP,SCC,fct
      integer for, fty
      common/model/for, fty
      integer ARI, tra
      common/model/ari,tra

c      print *,'PPIND: ',PPIND
      IF(tra.EQ.1)THEN
      IF(PPIND.EQ.0)THEN
C        PRINT *,'ROOT EQUALITY SWITCH: ',REQSW
      END IF
      END IF
c      print *,'REQSW: ',REQSW
      IF(REQSW.EQ.0)THEN
        CALL RESG0
      ELSE
        CALL RESG1
c        PRINT *, 'CALL OF RESG1 COMPLETED'
      END IF
      U=CSZ
      DO 100 T=1,LEN
      U=U+DLOG(VT(T))
  100 CONTINUE
c      PRINT *,'SUM LOG VARIANCES FORMED'
      U=DEXP((CSO/LEN)*U)
      GMNEW=U
      DO 101 T=1,LEN
      V=ERR(T)*DSQRT(U/VT(T))
      IF(PPIND.EQ.0)THEN
        RES(T)=V
      ELSE
        PRES(PPIND,T)=V
      END IF
  101 CONTINUE
      RETURN
      END
